==> gorilla-notes-0.5.11.jar: public/js/compiled/cljs-runtime/gorilla_notes.components.markdown.js <==
goog.provide('gorilla_notes.components.markdown');
var module$node_modules$react_markdown$lib$react_markdown=shadow.js.require("module$node_modules$react_markdown$lib$react_markdown", {});
var module$node_modules$remark_gfm$index=shadow.js.require("module$node_modules$remark_gfm$index", {});
var module$node_modules$remark_math$index=shadow.js.require("module$node_modules$remark_math$index", {});
var module$node_modules$react_katex$dist$react_katex=shadow.js.require("module$node_modules$react_katex$dist$react_katex", {});
var module$node_modules$react$index=shadow.js.require("module$node_modules$react$index", {});
cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"DBG","DBG",601806953),module$node_modules$react_katex$dist$react_katex.InlineMath], null)], 0));
gorilla_notes.components.markdown.renderers = ({"inlineMath": (function (v){
return module$node_modules$react$index.createElement(module$node_modules$react_katex$dist$react_katex.InlineMath,({"math": v.value}));
}), "math": (function (p__24001){
var map__24002 = p__24001;
var map__24002__$1 = (((((!((map__24002 == null))))?(((((map__24002.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__24002.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.cljs$core$IFn$_invoke$arity$2(cljs.core.hash_map,map__24002):map__24002);
var value = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__24002__$1,new cljs.core.Keyword(null,"value","value",305978217));
return module$node_modules$react$index.createElement(module$node_modules$react_katex$dist$react_katex.BlockMath,({"math": value}));
})});
/**
 * reagent markdown render component
 * usage:
 *  [markdown markdown-string]
 */
gorilla_notes.components.markdown.markdown = (function gorilla_notes$components$markdown$markdown(md){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div","div",1057191632),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,">",">",-555517146),module$node_modules$react_markdown$lib$react_markdown,new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"plugins","plugins",1900073717),[module$node_modules$remark_math$index,module$node_modules$remark_gfm$index],new cljs.core.Keyword(null,"renderers","renderers",-1460292282),gorilla_notes.components.markdown.renderers,new cljs.core.Keyword(null,"children","children",-940561982),md], null)], null)], null);
});

//# sourceMappingURL=gorilla_notes.components.markdown.js.map

==> gorilla-notes-0.5.12.jar: public/js/compiled/cljs-runtime/gorilla_notes.components.markdown.js <==
goog.provide('gorilla_notes.components.markdown');
var module$node_modules$react_markdown$lib$react_markdown=shadow.js.require("module$node_modules$react_markdown$lib$react_markdown", {});
var module$node_modules$remark_gfm$index=shadow.js.require("module$node_modules$remark_gfm$index", {});
var module$node_modules$remark_math$index=shadow.js.require("module$node_modules$remark_math$index", {});
var module$node_modules$react_katex$dist$react_katex=shadow.js.require("module$node_modules$react_katex$dist$react_katex", {});
var module$node_modules$react$index=shadow.js.require("module$node_modules$react$index", {});
cljs.core.println.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"DBG","DBG",601806953),module$node_modules$react_katex$dist$react_katex.InlineMath], null)], 0));
gorilla_notes.components.markdown.renderers = ({"inlineMath": (function (v){
return module$node_modules$react$index.createElement(module$node_modules$react_katex$dist$react_katex.InlineMath,({"math": v.value}));
}), "math": (function (p__66137){
var map__66138 = p__66137;
var map__66138__$1 = cljs.core.__destructure_map(map__66138);
var value = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__66138__$1,new cljs.core.Keyword(null,"value","value",305978217));
return module$node_modules$react$index.createElement(module$node_modules$react_katex$dist$react_katex.BlockMath,({"math": value}));
})});
/**
 * reagent markdown render component
 * usage:
 *  [markdown markdown-string]
 */
gorilla_notes.components.markdown.markdown = (function gorilla_notes$components$markdown$markdown(md){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"div","div",1057191632),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,">",">",-555517146),module$node_modules$react_markdown$lib$react_markdown,new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"plugins","plugins",1900073717),[module$node_modules$remark_math$index,module$node_modules$remark_gfm$index],new cljs.core.Keyword(null,"renderers","renderers",-1460292282),gorilla_notes.components.markdown.renderers,new cljs.core.Keyword(null,"children","children",-940561982),md], null)], null)], null);
});

//# sourceMappingURL=gorilla_notes.components.markdown.js.map
